==> nextcloud-13.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/ar.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "النشاطات",
    "An error occurred while loading activities" : "حدث خطأ اثناء تحميل النشاطات ",
    "No activity yet" : "لا يوجد أي أنشطة حتى الأن",
    "Load more activities" : "تحميل المزيد من النشاطات",
    "Copied!" : "تم النسخ!",
    "Not supported!" : "غير مدعوم!",
    "Press ⌘-C to copy." : "اضغط  C-⌘ للنسخ.",
    "Press Ctrl-C to copy." : "اضغط Ctrl-C للنسخ.",
    "Home" : "الرئيسية",
    "{name} (invisible)" : "{الأسم} (مخفي)",
    "{name} (restricted)" : "{الأسم} (مخصص)",
    "in {path}" : "في {المسار}",
    "This stream will show events like additions, changes & shares" : "هذا التدفق سيظهر لك الاحداث، مثل الإضافة والتغيير والمشاركة",
    "There are no events for this filter" : "لا توجد هناك فعاليات وفق ما خصصته",
    "Today" : "اليوم",
    "Yesterday" : "الأمس",
    "Open file" : "فتح ملف",
    "Personal activity feed for %s" : "النشاطات الشخصية المضافة ل%s",
    "Your feed URL is invalid" : "رابط التغدية الخاص بك غير شغال",
    "Your settings have been updated." : "تم تحديث الإعدادات الخاصة بك.",
    "Settings have been updated." : "تم تحديث الاعدادات ",
    "Mail" : "البريد",
    "Stream" : "البث",
    "All activities" : "جميع النشاطات",
    "By others" : "بواسطة أخرين",
    "By you" : "بواسطتك",
    "\"remote user\"" : "\"مستخدم عن بعد\"",
    "Hello %s" : "اهلا %s",
    "Hello %s," : "مرحبا %s،",
    "There was some activity at %s" : "يوجد بعض الانشطة في %s",
    "_and %n more _::_and %n more _" : ["و %n المزيد","و %n المزيد","و %n المزيد","و %n المزيد","و %n المزيد","و %n المزيد"],
    "Activity notification" : "تنبيه النشاط",
    ", " : ",",
    "%s and %s" : "%s و %s",
    "Activity" : "نشاط",
    "Activity feed" : "تغذية الأنشطة",
    "Send activity emails" : "ارسل ايميل عن النشاطات",
    "Default settings" : "الإعدادات الإفتراضية",
    "Configure the default activity settings for new users." : "عمل اعدادات النشاط الافتراضى للمستخدمين الجدد",
    "List your own actions in the stream" : "اعرض عملياتك في التدفق",
    "Notify about your own actions via email" : "التنبيه عن أنشطتي عبر البريد الإلكتروني",
    "You need to set up your email address before you can receive notification emails." : "عليك إعداد عنوان البريد الإلكتروني الخاص بك قبل البدأ باستقبال رسائل إلكترونية تنبيهيه ",
    "Send emails:" : "إرسال رسائل إلكترونية ",
    "As soon as possible" : "بإسرع وقت ممكن",
    "Hourly" : "مرة كل ساعة",
    "Daily" : "يومي",
    "Weekly" : "أسبوعي",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "اختر أى نشاط تريد ان تحصل منه على اشعار خلال البريد الالكترونى و أيهم يظهر على قائمه نشاط التطبيق ",
    "Choose which activities you want to see in your stream." : "اختار اي نشاط ترغب في اضافتها للستريم",
    "Settings" : "الإعدادات",
    "Enable RSS feed" : "تفعيل خاصية الخلاصات",
    "RSS feed" : "مزود ار أس أس ",
    "No more events to load" : "لا توجد أي أحداث للتحميل",
    "Files" : "الملفات",
    "Error loading activities" : "خطأ فى تحميل النشاطات ",
    "No activities" : "لا نشاطات",
    "You are receiving this email because the following things happened at %s" : "إنك تتلقى هذه الرسالة الإلكترونية بسبب حدوث الأمور التالية%s",
    "* %1$s - %2$s" : "*%1$s-%2$s",
    "_* and %n more _::_* and %n more _" : ["* بقي %n","* بقي %n","* بقي %n","* بقي %n","* بقي %n","* بقي %n"]
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> nextcloud-14.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/ar.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "النشاطات",
    "An error occurred while loading activities" : "حدث خطأ اثناء تحميل النشاطات ",
    "No activity yet" : "لا يوجد أي أنشطة حتى الأن",
    "Load more activities" : "تحميل المزيد من النشاطات",
    "Copied!" : "تم النسخ!",
    "Not supported!" : "غير مدعوم!",
    "Press ⌘-C to copy." : "اضغط  C-⌘ للنسخ.",
    "Press Ctrl-C to copy." : "اضغط Ctrl-C للنسخ.",
    "Home" : "الرئيسية",
    "{name} (invisible)" : "{الأسم} (مخفي)",
    "{name} (restricted)" : "{الأسم} (مخصص)",
    "in {path}" : "في {المسار}",
    "This stream will show events like additions, changes & shares" : "هذا التدفق سيظهر لك الاحداث، مثل الإضافة والتغيير والمشاركة",
    "There are no events for this filter" : "لا توجد هناك فعاليات وفق ما خصصته",
    "Today" : "اليوم",
    "Yesterday" : "الأمس",
    "Open file" : "فتح ملف",
    "Personal activity feed for %s" : "النشاطات الشخصية المضافة ل%s",
    "Your feed URL is invalid" : "رابط التغدية الخاص بك غير شغال",
    "Your settings have been updated." : "تم تحديث الإعدادات الخاصة بك.",
    "Settings have been updated." : "تم تحديث الاعدادات ",
    "All activities" : "جميع النشاطات",
    "By others" : "بواسطة أخرين",
    "By you" : "بواسطتك",
    "\"remote user\"" : "\"مستخدم عن بعد\"",
    "Activity notification for %s" : "تنبيه النشاط %s",
    "Hello %s" : "اهلا %s",
    "Hello %s," : "مرحبا %s،",
    "There was some activity at %s" : "يوجد بعض الانشطة في %s",
    "_and %n more _::_and %n more _" : ["و %n المزيد","و %n المزيد","و %n المزيد","و %n المزيد","و %n المزيد","و %n المزيد"],
    ", " : ",",
    "%s and %s" : "%s و %s",
    "Mail" : "البريد",
    "Stream" : "البث",
    "Activity" : "نشاط",
    "Activity feed" : "تغذية الأنشطة",
    "Send activity emails" : "ارسل ايميل عن النشاطات",
    "Default settings" : "الإعدادات الإفتراضية",
    "Configure the default activity settings for new users." : "عمل اعدادات النشاط الافتراضى للمستخدمين الجدد",
    "List your own actions in the stream" : "اعرض عملياتك في التدفق",
    "Notify about your own actions via email" : "التنبيه عن أنشطتي عبر البريد الإلكتروني",
    "You need to set up your email address before you can receive notification emails." : "عليك إعداد عنوان البريد الإلكتروني الخاص بك قبل البدأ باستقبال رسائل إلكترونية تنبيهيه ",
    "Send emails:" : "إرسال رسائل إلكترونية ",
    "As soon as possible" : "بإسرع وقت ممكن",
    "Hourly" : "مرة كل ساعة",
    "Daily" : "يومي",
    "Weekly" : "أسبوعي",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "اختر أى نشاط تريد ان تحصل منه على اشعار خلال البريد الالكترونى و أيهم يظهر على قائمه نشاط التطبيق ",
    "Choose which activities you want to see in your stream." : "اختار اي نشاط ترغب في اضافتها للستريم",
    "Settings" : "الإعدادات",
    "Enable RSS feed" : "تفعيل خاصية الخلاصات",
    "RSS feed" : "مزود ار أس أس ",
    "No more events to load" : "لا توجد أي أحداث للتحميل",
    "Files" : "الملفات",
    "Activity notification" : "تنبيه النشاط"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
